@@ -9,9 +9,7 @@ fn main() {
     println!("cargo:rerun-if-env-changed=CFLAGS");
     println!("cargo:rerun-if-env-changed=LDFLAGS");
     println!("cargo:rerun-if-env-changed=RUSTFLAGS");
-    println!("cargo:rerun-if-env-changed=ORJSON_DISABLE_WRITEEXT");
     println!("cargo:rerun-if-env-changed=ORJSON_DISABLE_YYJSON");
-    println!("cargo:rerun-if-env-changed=ORJSON_ENABLE_WRITEEXT");
 
     let py_cfg = pyo3_build_config::get();
     py_cfg.emit_pyo3_cfgs();
@@ -32,14 +30,6 @@ fn main() {
         println!("cargo:rustc-cfg=feature=\"trusted_len\"");
     }
 
-    if env::var("ORJSON_DISABLE_WRITEEXT").is_ok() {
-    } else if env::var("ORJSON_ENABLE_WRITEEXT").is_ok()
-        || env::var("CARGO_CFG_TARGET_OS").unwrap() == "macos"
-        || env::var("CARGO_CFG_TARGET_ENV").unwrap() == "gnu"
-    {
-        println!("cargo:rustc-cfg=feature=\"writeext\"");
-    }
-
     if env::var("ORJSON_DISABLE_YYJSON").is_ok() {
         if env::var("CARGO_FEATURE_YYJSON").is_ok() {
             panic!("ORJSON_DISABLE_YYJSON and --features=yyjson both enabled.")
