@@ -8,7 +8,9 @@ mod default;
 mod dict;
 mod error;
 mod float;
+mod fragment;
 mod int;
+mod json;
 mod list;
 mod numpy;
 mod pyenum;
@@ -18,7 +20,4 @@ mod tuple;
 mod uuid;
 mod writer;
 
-#[cfg(feature = "writeext")]
-mod json;
-
 pub use serializer::serialize;
