@@ -26,29 +26,34 @@ impl TupleSerializer {
             ptr: ptr,
             opts: opts,
             default_calls: default_calls,
-            recursion: recursion,
+            recursion: recursion + 1,
             default: default,
         }
     }
 }
 
-impl<'p> Serialize for TupleSerializer {
+impl Serialize for TupleSerializer {
     #[inline(never)]
     fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
     where
         S: Serializer,
     {
-        let mut seq = serializer.serialize_seq(None).unwrap();
-        for i in 0..=ffi!(PyTuple_GET_SIZE(self.ptr)) - 1 {
-            let elem = nonnull!(ffi!(PyTuple_GET_ITEM(self.ptr, i as isize)));
-            seq.serialize_element(&PyObjectSerializer::new(
-                elem.as_ptr(),
-                self.opts,
-                self.default_calls,
-                self.recursion + 1,
-                self.default,
-            ))?
+        if ffi!(Py_SIZE(self.ptr)) == 0 {
+            serializer.serialize_seq(Some(0)).unwrap().end()
+        } else {
+            let mut seq = serializer.serialize_seq(None).unwrap();
+            for i in 0..=ffi!(Py_SIZE(self.ptr)) as usize - 1 {
+                let elem = ffi!(PyTuple_GET_ITEM(self.ptr, i as isize));
+                let value = PyObjectSerializer::new(
+                    elem,
+                    self.opts,
+                    self.default_calls,
+                    self.recursion,
+                    self.default,
+                );
+                seq.serialize_element(&value)?;
+            }
+            seq.end()
         }
-        seq.end()
     }
 }
